==> ehome-rcm-0.9.0.tgz: package/es/lottie-animation/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

var LottieAnimation =
/*#__PURE__*/
function (_Component) {
  _inherits(LottieAnimation, _Component);

  function LottieAnimation(props) {
    var _this;

    _classCallCheck(this, LottieAnimation);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(LottieAnimation).call(this, props));

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "saveLoadingRef", function (el) {
      _this.loadingRef = el;
    });

    _this.loadingRef = null;
    _this.animInstances = {};
    return _this;
  }

  _createClass(LottieAnimation, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var lottie = window.lottie;
      var _this$props = this.props,
          animationData = _this$props.animationData,
          config = _this$props.config;

      if (lottie && lottie.loadAnimation) {
        var loadAnimationConfig = _extends(config, {
          // the path to the animation json
          animationData: animationData,
          // the dom element that will contain the animation
          container: this.loadingRef
        });

        this.animInstances = lottie.loadAnimation(loadAnimationConfig);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var prefixCls = 'eh-lottie';
      var className = this.props.className;
      var wrapCls = classNames(prefixCls, className);
      return React.createElement("div", {
        className: wrapCls,
        ref: this.saveLoadingRef
      });
    }
  }]);

  return LottieAnimation;
}(Component);

_defineProperty(LottieAnimation, "propTypes", {
  className: PropTypes.string,
  // lottie 渲染动画时需要的动画 json 数据
  animationData: PropTypes.object.isRequired,
  //eslint-disable-line
  // 控制 lottie 动画渲染时的其他三个参数
  config: PropTypes.shape({
    autoplay: PropTypes.bool,
    loop: PropTypes.oneOfType([PropTypes.bool, PropTypes.number]),
    renderer: PropTypes.oneOf(['svg', 'canvas', 'html'])
  })
});

_defineProperty(LottieAnimation, "defaultProps", {
  className: '',
  config: {
    autoplay: true,
    loop: true,
    renderer: 'svg'
  }
});

export default LottieAnimation;

==> ehome-rcm-0.10.2.tgz: package/es/lottie-animation/index.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';

var LottieAnimation =
/*#__PURE__*/
function (_Component) {
  _inherits(LottieAnimation, _Component);

  function LottieAnimation(props) {
    var _this;

    _classCallCheck(this, LottieAnimation);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(LottieAnimation).call(this, props));

    _defineProperty(_assertThisInitialized(_this), "saveLoadingRef", function (el) {
      _this.loadingRef = el;
    });

    _this.loadingRef = null;
    _this.animInstances = {};
    return _this;
  }

  _createClass(LottieAnimation, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      var lottie = window.lottie;
      var _this$props = this.props,
          animationData = _this$props.animationData,
          config = _this$props.config;

      if (lottie && lottie.loadAnimation) {
        var loadAnimationConfig = _extends(config, {
          // the path to the animation json
          animationData: animationData,
          // the dom element that will contain the animation
          container: this.loadingRef
        });

        this.animInstances = lottie.loadAnimation(loadAnimationConfig);
      }
    }
  }, {
    key: "render",
    value: function render() {
      var prefixCls = 'eh-lottie';
      var className = this.props.className;
      var wrapCls = classNames(prefixCls, className);
      return React.createElement("div", {
        className: wrapCls,
        ref: this.saveLoadingRef
      });
    }
  }]);

  return LottieAnimation;
}(Component);

_defineProperty(LottieAnimation, "propTypes", {
  className: PropTypes.string,
  // lottie 渲染动画时需要的动画 json 数据
  animationData: PropTypes.object.isRequired,
  //eslint-disable-line
  // 控制 lottie 动画渲染时的其他三个参数
  config: PropTypes.shape({
    autoplay: PropTypes.bool,
    loop: PropTypes.oneOfType([PropTypes.bool, PropTypes.number]),
    renderer: PropTypes.oneOf(['svg', 'canvas', 'html'])
  })
});

_defineProperty(LottieAnimation, "defaultProps", {
  className: '',
  config: {
    autoplay: true,
    loop: true,
    renderer: 'svg'
  }
});

export default LottieAnimation;
